msinvar: Package for computing various moduli space invariants
==============================================================

Description
-----------

This is a Sage package for computing various moduli space invariants.

License
-------

GPLv2

Upstream Contact
----------------

- https://github.com/smzg/msinvar
- https://github.com/passagemath/passagemath-pkg-msinvar
